==> haskell-servant-swagger-1.1.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.3.1
id: servant-swagger-1.1.3.1-AqOFJuyoiWN8Lq33jVHHWG
key: servant-swagger-1.1.3.1-AqOFJuyoiWN8Lq33jVHHWG
license: BSD3
copyright: (c) 2015-2016, Servant contributors
maintainer: nickolay.kudasov@gmail.com
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Please see README.md
category: Web
author: David Johnson, Nickolay Kudasov
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Test Servant.Swagger.TypeLevel
    Servant.Swagger.Internal Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap
abi: 129a4694cb083b0406a5d4e49015bd20
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-swagger-1.1.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-swagger-1.1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-swagger-1.1.3.1
hs-libraries: HSservant-swagger-1.1.3.1-AqOFJuyoiWN8Lq33jVHHWG
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0
    bytestring-0.10.8.1 hspec-2.4.4-1VIfvOpCdEBEKtorUJe9Ux
    http-media-0.7.1-CpUC2f3C6fm1nyvIESvsCy
    insert-ordered-containers-0.2.1.0-GFmfLiRPDp3A5YcI6tzZAQ
    lens-4.15.3-60anFPcl0sa4AbScjQzShN
    servant-0.11-El9ZNiUW0kX3q13DPeqxkV
    swagger2-2.1.4.1-3YnILDpH4zyLNTdDdOcjTQ
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.3.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.3.1
id: servant-swagger-1.1.3.1-4PI2aP1nZOHAF1gf5zyDQr
key: servant-swagger-1.1.3.1-4PI2aP1nZOHAF1gf5zyDQr
license: BSD3
copyright: (c) 2015-2016, Servant contributors
maintainer: nickolay.kudasov@gmail.com
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Please see README.md
category: Web
author: David Johnson, Nickolay Kudasov
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Test Servant.Swagger.TypeLevel
    Servant.Swagger.Internal Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap
abi: 6aa9730292141339bec6a322fba69c2b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-swagger-1.1.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-swagger-1.1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-swagger-1.1.3.1
hs-libraries: HSservant-swagger-1.1.3.1-4PI2aP1nZOHAF1gf5zyDQr
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0
    bytestring-0.10.8.1 hspec-2.4.4-1VIfvOpCdEBEKtorUJe9Ux
    http-media-0.7.1-CpUC2f3C6fm1nyvIESvsCy
    insert-ordered-containers-0.2.1.0-BlF2QbTJU4LHqxIIIp1XCg
    lens-4.15.3-6ghM1rB2SVx7pTJuxB037l
    servant-0.11-El9ZNiUW0kX3q13DPeqxkV
    swagger2-2.1.4.1-KSgLYyGqqwbDCyCFq3uA0j
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
